%This script generates 31 frames of high resolution movie of energy consumption Lorenz curves%
%Making movie files need call ffmpegtranscode() in MATLAB. Examples can be
%found in ffmpegtranscode.m in ffmpeg toolbox.%

%Author: Qin Liu%

%read data%
%read global energy consumption, population and energy consumption per
%capita.%
ce_mov=xlsread('Global_ectot','a3:ah225');%energy consumption%
pop_mov=xlsread('Global_pop','a3:ah225');%population%
cepercap_mov=xlsread('Global_ecpercap','a3:ah225');%consumption per capita%
format long;

%Calculate cumulative data for population and consumption for 32 years from
%1980 to 2011. In current movie, year 2011 is not included.%
for j=1:32;
    ce=ce_mov(:,j);
pop=pop_mov(:,j);
cepercap=cepercap_mov(:,j);
data=[cepercap,ce,pop];
lorentz=sortrows(data,1);%sort data by consumption per capita%
s_ce=lorentz(:,2);
s_pop=lorentz(:,3);
ceratio(:,j)=s_ce/sum(s_ce);
popratio(:,j)=s_pop/sum(s_pop);
for i=1:223;
    cm_ceratio(i,j)=sum(ceratio(1:i,j:j));
end

for i=1:223;
    cm_popratio(i,j)=sum(popratio(1:i,j:j));
end
end

%Generate Lorenz curves for first 11 years%
for j=1:11;
x4=0:0.0001:1;
y4=x4+(1-x4).*log(1-x4);%theory line%
x5=0:0.0001:1;
y5=1-x5;
y6=x5;
plot(x4,y4,'k-','linewidth',1.5);%diagonal line%
hold on
plot(cm_popratio(:,1),cm_ceratio(:,1),'.-','Color',[0 0 1]);%lorenz curve%
hold on
plot(x5,y5,'k--');
hold on
plot(x5,y6,'k.','markersize',1.5);
hold on
plot(cm_popratio(:,j),cm_ceratio(:,j),'r.-');
hold on
%highlight few points representing important countries%
highlitx1=[cm_popratio(76,1),cm_popratio(113,1),cm_popratio(137,1),cm_popratio(186,1),cm_popratio(189,1),cm_popratio(194,1),cm_popratio(213,1)];
highlity1=[cm_ceratio(76,1),cm_ceratio(113,1),cm_ceratio(137,1),cm_ceratio(186,1),cm_ceratio(189,1),cm_ceratio(194,1),cm_ceratio(213,1)];
plot(highlitx1,highlity1,'b.','Markersize',25);
hold off
axis([0,1,0,1]);%set axis properties%
set(gca,'xtick',[0:0.1:1])
set(gca,'ytick',[0:0.1:1])
axis square;

%add timer%
year=1979+j;
timer=text(0.3,0.242,num2str(year));
set(timer,'Fontsize',20,'Fontweight','Bold');
%labels, title and legend%
%The positions of labels are already well-adjusted.%
t6=text(0.03,0.6,'Data source: EIA');
t14=text(.23,.07,'IND');
t15=text(.57,.07,'CHN');
t16=text(.68,.1,'BRA');
t17=text(.855,.38,'UK');
t18=text(.83,.322,'FRA');
t18a=text(1.01,0.95,'USA');
t18b=text(0.925,0.57,'USSR');
set(t6,'Fontsize',15);
set(t14,'Fontsize',16,'Color','b');
set(t15,'Fontsize',16,'Color','b');
set(t16,'Fontsize',16,'Color','b');
set(t17,'Fontsize',16,'Color','b');
set(t18,'Fontsize',16,'Color','b');
set(t18a,'Fontsize',16,'Color','b');
set(t18b,'Fontsize',16,'Color','b');
t=title('Lorenz Plot of Global Energy Consumption');
t19=xlabel('Fraction of World Population');
t20=ylabel('Fraction of World Energy Consumption');
set(t,'Fontsize',16);
set(t19,'Fontsize',16);
set(t20,'Fontsize',16);
h=legend('Exponential G=0.50','1980 G=0.66',2);
set(h,'Fontsize',16);
set(gcf,'inverthardcopy','off');
print(gcf,'-r150','-dpng',num2str(j));%print .png files with resolution of 150.%
end

%Generate plots from 1991 to 2000.%
%Codes are parallel to the upper section for first 11 years.%
for j=1:10;
  x4=0:0.0001:1;
y4=x4+(1-x4).*log(1-x4);
x5=0:0.0001:1;
y5=1-x5;
y6=x5;
plot(x4,y4,'k-','linewidth',1.5);
hold on
plot(cm_popratio(:,1),cm_ceratio(:,1),'.-','Color',[0 0 1]);
hold on
plot(cm_popratio(:,11),cm_ceratio(:,11),'.-','Color',[.3 .2 0]);
hold on

plot(cm_popratio(:,j+11),cm_ceratio(:,j+11),'r.-');
hold on
plot(x5,y5,'k--');
hold on
plot(x5,y6,'k.','markersize',1.5);
hold on

highlitx1=[cm_popratio(76,1),cm_popratio(113,1),cm_popratio(137,1),cm_popratio(186,1),cm_popratio(189,1),cm_popratio(194,1),cm_popratio(213,1)];
highlity1=[cm_ceratio(76,1),cm_ceratio(113,1),cm_ceratio(137,1),cm_ceratio(186,1),cm_ceratio(189,1),cm_ceratio(194,1),cm_ceratio(213,1)];
plot(highlitx1,highlity1,'b.','Markersize',25);
hold off
axis([0,1,0,1]);
set(gca,'xtick',[0:0.1:1])
set(gca,'ytick',[0:0.1:1])
axis square;
year=1990+j;
timer=text(0.3,0.242,num2str(year));
set(timer,'Fontsize',20,'Fontweight','Bold');

t6=text(0.03,0.6,'Data source: EIA');
t14=text(.23,.07,'IND');
t15=text(.57,.07,'CHN');
t16=text(.68,.1,'BRA');
t17=text(.855,.38,'UK');
t18=text(.83,.322,'FRA');
t18a=text(1.01,0.95,'USA');
t18b=text(0.925,0.57,'USSR');
set(t6,'Fontsize',15);
set(t14,'Fontsize',16,'Color','b');
set(t15,'Fontsize',16,'Color','b');
set(t16,'Fontsize',16,'Color','b');
set(t17,'Fontsize',16,'Color','b');
set(t18,'Fontsize',16,'Color','b');
set(t18a,'Fontsize',16,'Color','b');
set(t18b,'Fontsize',16,'Color','b');


t=title('Lorenz Plot of Global Energy Consumption');
t19=xlabel('Fraction of World Population');
t20=ylabel('Fraction of World Energy Consumption');
set(t,'Fontsize',16);
set(t19,'Fontsize',16);
set(t20,'Fontsize',16);
h=legend('Exponential G=0.50','1980 G=0.66','1990 G=0.64',2);
set(h,'Fontsize',16);
set(gcf,'inverthardcopy','off');
print(gcf,'-r150','-dpng',num2str(j+11));
end

%Generate plots from 2001 to 2009%
%Codes are parallel to the upper two sections%
for j=1:9;
   x4=0:0.0001:1;
y4=x4+(1-x4).*log(1-x4);
x5=0:0.0001:1;
y5=1-x5;
y6=x5;
plot(x4,y4,'k-','linewidth',1.5);
hold on
plot(cm_popratio(:,1),cm_ceratio(:,1),'.-','Color',[0 0 1]);
hold on
plot(cm_popratio(:,11),cm_ceratio(:,11),'.-','Color',[.3 .2 0]);
hold on
plot(cm_popratio(:,21),cm_ceratio(:,21),'.-','Color',[0 .4 .3]);
hold on
plot(cm_popratio(:,j+21),cm_ceratio(:,j+21),'r.-');
hold on
plot(x5,y5,'k--');
hold on
plot(x5,y6,'k.','markersize',1.5);
hold on

highlitx1=[cm_popratio(76,1),cm_popratio(113,1),cm_popratio(137,1),cm_popratio(186,1),cm_popratio(189,1),cm_popratio(194,1),cm_popratio(213,1)];
highlity1=[cm_ceratio(76,1),cm_ceratio(113,1),cm_ceratio(137,1),cm_ceratio(186,1),cm_ceratio(189,1),cm_ceratio(194,1),cm_ceratio(213,1)];
plot(highlitx1,highlity1,'b.','Markersize',25);
hold off
axis([0,1,0,1]);
set(gca,'xtick',[0:0.1:1])
set(gca,'ytick',[0:0.1:1])
axis square;
year=2000+j;
timer=text(0.3,0.242,num2str(year));
set(timer,'Fontsize',20,'Fontweight','Bold');

t6=text(0.03,0.6,'Data source: EIA');
t14=text(.23,.07,'IND');
t15=text(.57,.07,'CHN');
t16=text(.68,.1,'BRA');
t17=text(.855,.38,'UK');
t18=text(.83,.322,'FRA');
t18a=text(1.01,0.95,'USA');
t18b=text(0.925,0.57,'USSR');
set(t6,'Fontsize',15);
set(t14,'Fontsize',16,'Color','b');
set(t15,'Fontsize',16,'Color','b');
set(t16,'Fontsize',16,'Color','b');
set(t17,'Fontsize',16,'Color','b');
set(t18,'Fontsize',16,'Color','b');
set(t18a,'Fontsize',16,'Color','b');
set(t18b,'Fontsize',16,'Color','b');

t=title('Lorenz Plot of Global Energy Consumption');
t19=xlabel('Fraction of World Population');
t20=ylabel('Fraction of World Energy Consumption');
set(t,'Fontsize',16);
set(t19,'Fontsize',16);
set(t20,'Fontsize',16);
h=legend('Exponential G=0.50','1980 G=0.66','1990 G=0.64','2000 G=0.62',2);
set(h,'Fontsize',16);
set(gcf,'inverthardcopy','off');
print(gcf,'-r150','-dpng',num2str(j+21));   
end

%Generate the last frame%
j=31;
x4=0:0.0001:1;
y4=x4+(1-x4).*log(1-x4);
x5=0:0.0001:1;
y5=1-x5;
y6=x5;
plot(x4,y4,'k-','linewidth',1.5);
hold on
plot(cm_popratio(:,1),cm_ceratio(:,1),'.-','Color',[0 0 1]);
hold on
plot(cm_popratio(:,11),cm_ceratio(:,11),'.-','Color',[.3 .2 0]);
hold on
plot(cm_popratio(:,21),cm_ceratio(:,21),'.-','Color',[0 .4 .3]);
hold on
plot(cm_popratio(:,31),cm_ceratio(:,31),'r.-');
hold on
plot(x5,y5,'k--');
hold on
plot(x5,y6,'k.','markersize',1.5);
hold on
%highlight a few points in 1980 curve%
highlitx1=[cm_popratio(76,1),cm_popratio(113,1),cm_popratio(137,1),cm_popratio(186,1),cm_popratio(189,1),cm_popratio(194,1),cm_popratio(213,1)];
highlity1=[cm_ceratio(76,1),cm_ceratio(113,1),cm_ceratio(137,1),cm_ceratio(186,1),cm_ceratio(189,1),cm_ceratio(194,1),cm_ceratio(213,1)];
plot(highlitx1,highlity1,'b.','Markersize',25);
hold on
%highlight a few points in 2010 curve%
highlitx32=[cm_popratio(73,31),cm_popratio(117,31),cm_popratio(139,31),cm_popratio(174,31),cm_popratio(184,31),cm_popratio(194,31),cm_popratio(209,31)];
highlity32=[cm_ceratio(73,31),cm_ceratio(117,31),cm_ceratio(139,31),cm_ceratio(174,31),cm_ceratio(184,31),cm_ceratio(194,31),cm_ceratio(209,31)];
plot(highlitx32,highlity32,'r.','Markersize',25);
hold off
axis([0,1,0,1]);
set(gca,'xtick',[0:0.1:1])
set(gca,'ytick',[0:0.1:1])
axis square;

t6=text(0.03,0.6,'Data source: EIA');

t7=text(0.31,0.11,'IND');
t8=text(0.41,0.18,'BRA');
t9=text(0.619,0.4,'CHN');
t10=text(0.718,0.51,'UK');
t11=text(0.72,0.55,'FRA');
t12=text(0.8,0.695,'RUS');
t13=text(0.88,0.96,'USA');
t14=text(.23,.07,'IND');
t15=text(.57,.07,'CHN');
t16=text(.68,.1,'BRA');
t17=text(.855,.38,'UK');
t18=text(.83,.322,'FRA');
t18a=text(1.01,0.95,'USA');
t18b=text(0.925,0.57,'USSR');

set(t6,'Fontsize',15);
set(t7,'Fontsize',16,'Color','r');
set(t8,'Fontsize',16,'Color','r');
set(t9,'Fontsize',16,'Color','r');
set(t10,'Fontsize',16,'Color','r');
set(t11,'Fontsize',16,'Color','r');
set(t12,'Fontsize',16,'Color','r');
set(t13,'Fontsize',16,'Color','r');

set(t14,'Fontsize',16,'Color','b');
set(t15,'Fontsize',16,'Color','b');
set(t16,'Fontsize',16,'Color','b');
set(t17,'Fontsize',16,'Color','b');
set(t18,'Fontsize',16,'Color','b');
set(t18a,'Fontsize',16,'Color','b');
set(t18b,'Fontsize',16,'Color','b');

t=title('Lorenz Plot of Global Energy Consumption');
t19=xlabel('Fraction of World Population');
t20=ylabel('Fraction of World Energy Consumption');
year=1979+j;
timer=text(0.3,0.242,num2str(year));
set(timer,'Fontsize',20,'Fontweight','Bold');
set(t,'Fontsize',16);
set(t19,'Fontsize',16);
set(t20,'Fontsize',16);
h=legend('Exponential G=0.50','1980 G=0.66','1990 G=0.64','2000 G=0.62','2010 G=0.55',2);
set(h,'Fontsize',16);
set(gcf,'inverthardcopy','off');
print(gcf,'-r150','-dpng',num2str(31));   